/**
 * @file
 * foundation_anchor_menu_block JavaScripts.
 *
 */
(function ($, Drupal) {
  Drupal.behaviors.foundation_anchor_menu_block = {
    attach: function (context, settings) {
      // Create namespace below Drupal for global variable access:
      Drupal.foundation_anchor_menu_block = (typeof Drupal.foundation_anchor_menu_block !== 'undefined') ? Drupal.foundation_anchor_menu_block : {};

      /*
        Promote options to make them editable (must run before this init):
        Example:
          settings.foundation_anchor_menu_block = {
            topBarSelector: '.top-bar-outer:first'
          };
      */
      // Magellan settings (https://get.foundation/sites/docs/magellan.html#js-options):
      var fambSettings = (typeof settings.foundation_anchor_menu_block !== 'undefined') ? settings.foundation_anchor_menu_block : {};
      var animationDuration = (typeof fambSettings.animationDuration !== 'undefined') ? fambSettings.animationDuration : 500;
      var animationEasing = (typeof fambSettings.animationEasing !== 'undefined') ? fambSettings.animationEasing : 'linear';
      var threshold = (typeof fambSettings.threshold !== 'undefined') ? fambSettings.threshold : 50;
      var activeClass = (typeof fambSettings.activeClass !== 'undefined') ? fambSettings.activeClass : 'is-active';
      var deeplinking = (typeof fambSettings.deeplinking !== 'undefined') ? fambSettings.deeplinking : false;
      var updateHistory = (typeof fambSettings.updateHistory !== 'undefined') ? fambSettings.updateHistory : false;
      var offset = (typeof fambSettings.offset !== 'undefined') ? fambSettings.offset : 0;

      // Further settings:
      // Calculate offset from topbar (.top-bar is a foundation standard), if given:
      var offsetTopBarSelector = (typeof fambSettings.offsetTopBarSelector !== 'undefined') ? fambSettings.offsetTopBarSelector : '.top-bar:first';
      if ($(offsetTopBarSelector).length > 0) {
        offset = offset + $(offsetTopBarSelector).outerHeight();
      }
      var anchorMenuActiveBodyClass = (typeof fambSettings.anchorMenuActiveBodyClass !== typeof undefined) ? fambSettings.anchorMenuActiveBodyClass : 'anchor-menu-active';

      var $fambAnchorMenu = $('[data-famb-anchor-menu]', context);
      if ($fambAnchorMenu.length > 0 && $('[data-anchor-menu-title]').length > 0) {
        var $fambAnchorMenuDropdownPane = $fambAnchorMenu.parents('.dropdown-pane:first');
        var $fambAnchorMenuDropdownPaneToggleButton = $fambAnchorMenuDropdownPane.prev('.button--anchor-menu-dropdown-toggle');
        var horizontalMenuBreakpoint = $fambAnchorMenu.data('anchor-menu-horizontal-breakpoint');
        $('body:first').addClass(anchorMenuActiveBodyClass);
        $('[data-anchor-menu-title][data-magellan-target]', context).each(function () {
          var $section = $(this);
          var sectionId = $section.attr('id');
          var sectionTitle = $section.attr('data-anchor-menu-title');
          if(sectionTitle.length > 0){
            $fambAnchorMenu.append('<li><a href="#' + sectionId + '">' + sectionTitle + '</a></li>');
          }
        });
        // We have to initialize Magellan manually, otherwise the magellan navigation is not initialized correctly (using data-magellan doesn't work on dynamic menus).
        // Assign to Drupal.foundation_anchor_menu_block.magellan to make it accessible globally:
        Drupal.foundation_anchor_menu_block.magellan = new Foundation.Magellan($fambAnchorMenu, {
          animationDuration: animationDuration,
          animationEasing: animationEasing,
          threshold: threshold,
          activeClass: activeClass,
          deeplinking: deeplinking,
          updateHistory: updateHistory,
          offset: offset,
        });

        // TODO: Check if the menu is higher than a single menu item, so we can consider it has a linebreak
        if (Foundation.MediaQuery.atLeast(horizontalMenuBreakpoint)) {
          $fambAnchorMenuDropdownPane.foundation('_destroy');
          $fambAnchorMenu.removeClass('vertical');
          if ($fambAnchorMenu.parent().is($fambAnchorMenuDropdownPane)) {
            // TODO: This needs a better solution - so that we have an "undo". Maybe a clone of the magellan menu, one for mobile one for larger screens, so we can simply toggle the visibility.
            $fambAnchorMenu.unwrap();
            // also remove the toggle button
            $fambAnchorMenuDropdownPaneToggleButton.remove();
          }
        } else {
          // Small devices > set active section as dropdown toggle button text
          // Initally set first menu item as text
          var activeAnchorSectionName = $fambAnchorMenu.find('a:first').text();
          $fambAnchorMenuDropdownPaneToggleButton.text(activeAnchorSectionName);
          $fambAnchorMenu.addClass('vertical');
          $fambAnchorMenu.on('update.zf.magellan', function () {
            var scopedAnchorSectionName = $fambAnchorMenu.find('a.is-active').text();
            if (scopedAnchorSectionName != activeAnchorSectionName && scopedAnchorSectionName != '') {
              $fambAnchorMenuDropdownPaneToggleButton.text(scopedAnchorSectionName);
            } else {
              $fambAnchorMenuDropdownPaneToggleButton.text(activeAnchorSectionName);
            }
          });
          // Close dropdown pane if an anchor link is clicked
          $fambAnchorMenu.find('a').on('click', function () {
            $fambAnchorMenuDropdownPane.foundation('close');
          });
        }
      }
    }
  }
})(jQuery, Drupal);
